summaryrefslogtreecommitdiffstats
path: root/mlir/include
diff options
context:
space:
mode:
authorNicolas Vasilache <ntv@google.com>2020-01-02 09:14:23 -0500
committerNicolas Vasilache <ntv@google.com>2020-01-02 09:30:34 -0500
commitafc25a43dc6cfd7dbbd875c68266f3d5ad20e9d4 (patch)
tree08b91630a5e8d02610ca1b932dd93b900e3e7d0c /mlir/include
parent13a7a4ccbf8ba946a02ce5972e0f93a2d38b5d54 (diff)
downloadbcm5719-llvm-afc25a43dc6cfd7dbbd875c68266f3d5ad20e9d4.tar.gz
bcm5719-llvm-afc25a43dc6cfd7dbbd875c68266f3d5ad20e9d4.zip
[mlir][Linalg] NFC - Rename LinalgGeneric -> GenericLinalg
Summary: This is part of an ongoing cleanup and uniformization work. Subscribers: mehdi_amini, rriddle, jpienaar, burmako, shauheen, antiagainst, llvm-commits Tags: #llvm Differential Revision: https://reviews.llvm.org/D72078
Diffstat (limited to 'mlir/include')
-rw-r--r--mlir/include/mlir/Dialect/Linalg/EDSC/Builders.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/mlir/include/mlir/Dialect/Linalg/EDSC/Builders.h b/mlir/include/mlir/Dialect/Linalg/EDSC/Builders.h
index 5c43c4080d8..c25c9d9f5ab 100644
--- a/mlir/include/mlir/Dialect/Linalg/EDSC/Builders.h
+++ b/mlir/include/mlir/Dialect/Linalg/EDSC/Builders.h
@@ -37,12 +37,12 @@ inline StringRef toString(IterType t) {
}
/// A StructuredIndexed represents a captured value that can be indexed and
/// passed to the `makeLinalgGenericOp`. It allows writing intuitive index
/// expressions such as:
///
/// ```
/// StructuredIndexed A(vA), B(vB), C(vC);
-/// makeLinalgGenericOp({A({m, n}), B({k, n})}, {C({m, n})}, ... );
+/// makeGenericLinalgOp({A({m, n}), B({k, n})}, {C({m, n})}, ... );
/// ```
struct StructuredIndexed {
StructuredIndexed(Value v) : value(v) {}
@@ -67,7 +67,7 @@ private:
inline void defaultRegionBuilder(ArrayRef<BlockArgument> args) {}
-Operation *makeLinalgGenericOp(
+Operation *makeGenericLinalgOp(
ArrayRef<IterType> iteratorTypes, ArrayRef<StructuredIndexed> inputs,
ArrayRef<StructuredIndexed> outputs,
function_ref<void(ArrayRef<BlockArgument>)> regionBuilder =
@@ -37,12 +37,12 @@ inline StringRef toString(IterType t) {
}
/// A StructuredIndexed represents a captured value that can be indexed and
-/// passed to the `makeLinalgGenericOp`. It allows writing intuitive index
+/// passed to the `makeGenericLinalgOp`. It allows writing intuitive index
/// expressions such as:
///
OpenPOWER on IntegriCloud